==> openGion6.1.1.0_dev.zip: uap/webapps/gf/src/org/opengion/hayabusa/taglib/AppearTag.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.hayabusa.taglib;

import org.opengion.hayabusa.common.HybsSystem;
import org.opengion.fukurou.util.ToString;						// 6.1.1.0 (2015/01/17)

import static org.opengion.fukurou.util.StringUtil.nval ;

/**
 * 指定された value 値の{&#064;XXXX} 変数が設定された場合のみ表示するタグです。
 *
 * value 値に、{&#064;XXXX} 変数を使用して、リクエスト値が設定された場合のみ
 * その値を表示します。これは、{&#064;XXXX} 変数と固定値を組み合わせた場合でも
 * 同様に、値が設定されていない場合は、使用されません。
 * defaultVal が設定されており、リクエスト値が設定されていない場合、defaultVal 値が
 * 使用されます。
 * このタグが使用されるケースの代表は、SQLでの order by 句です。一般のリクエスト時には、
 * order by 句をリクエストで設定して、ユーザーが検索する時に、切り替えができるように
 * します。別画面から、リンク等で画面を呼び出す場合は、通常 order by 句の条件まで、
 * 指定しません。そのような場合に備えて、og:appear タグでdefaultVal 値を設定しておき、
 * 未指定時の検索順を予め指定しておきます。
 *
 * @og.formSample
 * ●形式：&lt;og:appear startKey="[order by|…]" value="…" defaultVal="[…]" /&gt;
 * ●body：なし
 *
 * ●Tag定義
 *   &lt;og:appear
 *       startKey           【TAG】開始文字列を設定します(初期値:"")
 *       value            ○【TAG】値をセットします(指定された値が 設定されている場合のみ使用されます)(必須)
 *       defaultVal         【TAG】初期値を設定します(value値がNULLの場合に、この初期値が表示)
 *       quotCheck          【TAG】リクエスト情報の クォーティション(') 存在チェックを実施するかどうか[true/false]を設定します (初期値:USE_SQL_INJECTION_CHECK[=true])
 *       xssCheck           【TAG】リクエスト情報の HTMLTag開始/終了文字(&gt;&lt;) 存在チェックを実施するかどうか[true/false]を設定します (初期値:USE_XSS_CHECK[=true])
 *       debug              【TAG】デバッグ情報を出力するかどうか[true/false]を指定します(初期値:false)
 *   /&gt;
 *
 * ●使用例
 * &lt;!-- DB検索 SQL文記述 debug=&quot;true&quot; でSQL文を確認できます。--&gt;
 * &lt;og:query command=&quot;{&#064;command}&quot; debug=&quot;{&#064;debug}&quot; maxRowCount=&quot;{&#064;maxRowCount}&quot;&gt;
 *         select CLM,NAME_JA,LABEL_NAME,URL,KBSAKU,
 *                 SYSTEM_ID,LANG,FGJ,(CASE WHEN URL IS NULL THEN 0 ELSE 1 END) AS ONMARK
 *         from GF41
 *     &lt;!-- 検索条件でWhereTagを使用すれば{&#064;xxxx}がNULLの場合、その条件は無視されます。 --&gt;
 *     &lt;og:where&gt;
 *         &lt;og:and value = &quot;FGJ        in  (&#39;0&#39;,&#39;1&#39;)&quot;      /&gt;
 *         &lt;og:and value = &quot;SYSTEM_ID  =  &#39;{&#064;SYSTEM_ID}&#39;&quot;     /&gt;
 *         &lt;og:and value = &quot;LANG       =  &#39;{&#064;LANG}&#39;&quot;          /&gt;
 *         &lt;og:and value = &quot;CLM        like &#39;{&#064;CLM}%&#39;&quot;        /&gt;
 *         &lt;og:and value = &quot;NAME_JA    like &#39;{&#064;NAME_JA}%&#39;&quot;    /&gt;
 *         &lt;og:and value = &quot;LABEL_NAME like &#39;{&#064;LABEL_NAME}%&#39;&quot; /&gt;
 *         &lt;og:and value = &quot;KBSAKU     =    &#39;{&#064;KBSAKU}&#39;&quot;      /&gt;
 *     &lt;/og:where&gt;
 *     &lt;!-- ORDER BY句でAppearTagを使用すれば{&#064;ORDER_BY}がNULLの場合、ORDER BY句は無視されます。 --&gt;
 *     &lt;!-- また、{&#064;ORDER_BY}がNULLの場合に、defaultVal属性を指定すれば、その値でORDER BY表示されます。 --&gt;
 *     &lt;og:appear startKey = &quot;order by&quot; value = &quot;{&#064;ORDER_BY}&quot;
 *                 defaultVal = &quot;SYSTEM_ID,CLM,LANG&quot; /&gt;
 * &lt;/og:query&gt;
 *
 * @og.group 画面部品
 *
 * @version  4.0
 * @author	Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public class AppearTag extends CommonTagSupport {
	//* このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "5.7.8.1 (2014/07/18)" ;

	private static final long serialVersionUID = 578120140718L ;

	private String	startKey	= "";
	private String	value		;
	private String	defaultVal	;
	private boolean	quotCheck	= HybsSystem.sysBool( "USE_SQL_INJECTION_CHECK" );	// 5.7.8.1 (2014/07/18)
	private boolean	xssCheck	= HybsSystem.sysBool( "USE_XSS_CHECK" );			// 5.7.8.1 (2014/07/18)

	/**
	 * Taglibの終了タグが見つかったときに処理する doEndTag() を オーバーライドします。
	 *
	 * @og.rev 3.1.1.2 (2003/04/04) Tomcat4.1 対応。release2() を doEndTag()で呼ぶ。
	 * @og.rev 5.7.8.1 (2014/07/18) quotCheck,xssCheck 追加
	 *
	 * @return	後続処理の指示(EVAL_PAGE)
	 */
	@Override
	public int doEndTag() {
		debugPrint();		// 4.0.0 (2005/02/28)

		// 5.7.8.1 (2014/07/18) quotCheck,xssCheck 追加
		useQuotCheck( quotCheck );
		useXssCheck( xssCheck );

		String output = getRequestParameter( value );
		if( isNull() ) {
			output = defaultVal;
		}

		if( output != null ) {
			jspPrint( startKey + " " + output );
		}

		return EVAL_PAGE ;
	}

	/**
	 * タグリブオブジェクトをリリースします。
	 *
	 * キャッシュされて再利用されるので、フィールドの初期設定を行います。
	 *
	 * @og.rev 2.0.0.4 (2002/09/27) カスタムタグの release() メソッドを、追加
	 * @og.rev 3.1.1.2 (2003/04/04) Tomcat4.1 対応。release2() を doEndTag()で呼ぶ。
	 * @og.rev 5.7.8.1 (2014/07/18) quotCheck , xssCheck 追加
	 *
	 */
	@Override
	protected void release2() {
		super.release2();
		startKey    = "";
		value       = null;
		defaultVal  = null;
		quotCheck	= HybsSystem.sysBool( "USE_SQL_INJECTION_CHECK" );	// 5.7.8.1 (2014/07/18)
		xssCheck	= HybsSystem.sysBool( "USE_XSS_CHECK" );			// 5.7.8.1 (2014/07/18)
	}

	/**
	 * 【TAG】開始文字列を設定します(初期値:"")。
	 *
	 * @og.tag
	 * このキーは、バリューと接続される場合に空白文字を一つ挿入します。
	 *
	 * @param	val 開始文字列 (例：startKey="order by")
	 */
	public void setStartKey( final String val ) {
		startKey = nval( getRequestParameter( val ),startKey );
	}

	/**
	 * 【TAG】値をセットします(指定された値が 設定されている場合のみ使用されます)。
	 *
	 * @og.tag
	 * 指定された値が 設定されている場合のみ、開始文字列(startKey)と組み合わせれて、使用されます。
	 * これは、一般にvalue値が変動する場合に、defaultVal 等に重複する値を
	 * 設定したくない場合に使用します。{&#064;XXXX}文字が使用できます。
	 *
	 * @param	val 値
	 */
	public void setValue( final String val ) {
		value = val;
	}

	/**
	 * 【TAG】value属性に値がセットされていないとき使用する、初期値を指定します。
	 *
	 * @og.tag
	 * value属性に値がセットされていないときに、この初期値を使用します。
	 *
	 * @param	val 初期値
	 */
	public void setDefaultVal( final String val ) {
		defaultVal = nval( getRequestParameter( val ),defaultVal );
	}

	/**
	 * 【TAG】リクエスト情報の クォーティション(') 存在チェックを実施するかどうか[true/false]を設定します
	 *		(初期値:USE_SQL_INJECTION_CHECK[={@og.value org.opengion.hayabusa.common.SystemData#USE_SQL_INJECTION_CHECK}])。
	 *
	 * @og.tag
	 * ＳＱＬインジェクション対策の一つとして、暫定的ではありますが、SQLのパラメータに
	 * 渡す文字列にクォーティション(') を許さない設定にすれば、ある程度は防止できます。
	 * 数字タイプの引数には、 or 5=5 などのクォーティションを使用しないコードを埋めても、
	 * 数字チェックで検出可能です。文字タイプの場合は、必ず (')をはずして、
	 * ' or 'A' like 'A のような形式になる為、(')チェックだけでも有効です。
	 * (') が含まれていたエラーにする(true)／かノーチェックか(false)を指定します。
	 * (初期値:システム定数のUSE_SQL_INJECTION_CHECK[={@og.value org.opengion.hayabusa.common.SystemData#USE_SQL_INJECTION_CHECK}])。
	 *
	 * @og.rev 4.0.0.0 (2005/08/31) 新規追加
	 *
	 * @param   flag クォーティションチェック [true:する/それ以外:しない]
	 * @see		org.opengion.hayabusa.common.SystemData#USE_SQL_INJECTION_CHECK
	 */
	public void setQuotCheck( final String flag ) {
		quotCheck = nval( getRequestParameter( flag ),quotCheck );
	}

	/**
	 * 【TAG】リクエスト情報の HTMLTag開始/終了文字(&gt;&lt;) 存在チェックを実施するかどうか[true/false]を設定します
	 *		(初期値:USE_XSS_CHECK[={@og.value org.opengion.hayabusa.common.SystemData#USE_XSS_CHECK}])。
	 *
	 * @og.tag
	 * クロスサイトスクリプティング(XSS)対策の一環としてless/greater than signについてのチェックを行います。
	 * (&gt;&lt;) が含まれていたエラーにする(true)／かノーチェックか(false)を指定します。
	 * (初期値:システム定数のUSE_XSS_CHECK[={@og.value org.opengion.hayabusa.common.SystemData#USE_XSS_CHECK}])。
	 *
	 * @og.rev 5.0.0.2 (2009/09/15) 新規追加
	 *
	 * @param	flag	XSSチェック [true:する/false:しない]
	 * @see		org.opengion.hayabusa.common.SystemData#USE_XSS_CHECK
	 */
	public void setXssCheck( final String flag ) {
		xssCheck = nval( getRequestParameter( flag ),xssCheck );
	}

	/**
	 * このオブジェクトの文字列表現を返します。
	 * 基本的にデバッグ目的に使用します。
	 *
	 * @return このクラスの文字列表現
	 * @og.rtnNotNull
	 */
	@Override
	public String toString() {
		return ToString.title( this.getClass().getName() )
				.println( "VERSION"		,VERSION	)
				.println( "startKey"	,startKey	)
				.println( "value"		,value		)
				.println( "defaultVal"	,defaultVal	)
				.println( "Other..."	,getAttributes().getAttribute() )
				.fixForm().toString() ;
	}
}

==> openGion6.2.2.2_dev.zip: uap/webapps/gf/src/org/opengion/hayabusa/taglib/AppearTag.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.hayabusa.taglib;

import org.opengion.hayabusa.common.HybsSystem;
import org.opengion.fukurou.util.ToString;						// 6.1.1.0 (2015/01/17)

import static org.opengion.fukurou.util.StringUtil.nval ;

/**
 * 指定された value 値の{&#064;XXXX} 変数が設定された場合のみ表示するタグです。
 *
 * value 値に、{&#064;XXXX} 変数を使用して、リクエスト値が設定された場合のみ
 * その値を表示します。これは、{&#064;XXXX} 変数と固定値を組み合わせた場合でも
 * 同様に、値が設定されていない場合は、使用されません。
 * defaultVal が設定されており、リクエスト値が設定されていない場合、defaultVal 値が
 * 使用されます。
 * このタグが使用されるケースの代表は、SQLでの order by 句です。一般のリクエスト時には、
 * order by 句をリクエストで設定して、ユーザーが検索する時に、切り替えができるように
 * します。別画面から、リンク等で画面を呼び出す場合は、通常 order by 句の条件まで、
 * 指定しません。そのような場合に備えて、og:appear タグでdefaultVal 値を設定しておき、
 * 未指定時の検索順を予め指定しておきます。
 *
 * @og.formSample
 * ●形式：&lt;og:appear startKey="[order by|…]" value="…" defaultVal="[…]" /&gt;
 * ●body：なし
 *
 * ●Tag定義
 *   &lt;og:appear
 *       startKey           【TAG】開始文字列を設定します(初期値:"")
 *       value            ○【TAG】値をセットします(指定された値が 設定されている場合のみ使用されます)(必須)
 *       defaultVal         【TAG】初期値を設定します(value値がNULLの場合に、この初期値が表示)
 *       quotCheck          【TAG】リクエスト情報の シングルクォート(') 存在チェックを実施するかどうか[true/false]を設定します (初期値:USE_SQL_INJECTION_CHECK[=true])
 *       xssCheck           【TAG】リクエスト情報の HTMLTag開始/終了文字(&gt;&lt;) 存在チェックを実施するかどうか[true/false]を設定します (初期値:USE_XSS_CHECK[=true])
 *       debug              【TAG】デバッグ情報を出力するかどうか[true/false]を指定します(初期値:false)
 *   /&gt;
 *
 * ●使用例
 * &lt;!-- DB検索 SQL文記述 debug=&quot;true&quot; でSQL文を確認できます。--&gt;
 * &lt;og:query command=&quot;{&#064;command}&quot; debug=&quot;{&#064;debug}&quot; maxRowCount=&quot;{&#064;maxRowCount}&quot;&gt;
 *         select CLM,NAME_JA,LABEL_NAME,URL,KBSAKU,
 *                 SYSTEM_ID,LANG,FGJ,(CASE WHEN URL IS NULL THEN 0 ELSE 1 END) AS ONMARK
 *         from GF41
 *     &lt;!-- 検索条件でWhereTagを使用すれば{&#064;xxxx}がNULLの場合、その条件は無視されます。 --&gt;
 *     &lt;og:where&gt;
 *         &lt;og:and value = &quot;FGJ        in  (&#39;0&#39;,&#39;1&#39;)&quot;      /&gt;
 *         &lt;og:and value = &quot;SYSTEM_ID  =  &#39;{&#064;SYSTEM_ID}&#39;&quot;     /&gt;
 *         &lt;og:and value = &quot;LANG       =  &#39;{&#064;LANG}&#39;&quot;          /&gt;
 *         &lt;og:and value = &quot;CLM        like &#39;{&#064;CLM}%&#39;&quot;        /&gt;
 *         &lt;og:and value = &quot;NAME_JA    like &#39;{&#064;NAME_JA}%&#39;&quot;    /&gt;
 *         &lt;og:and value = &quot;LABEL_NAME like &#39;{&#064;LABEL_NAME}%&#39;&quot; /&gt;
 *         &lt;og:and value = &quot;KBSAKU     =    &#39;{&#064;KBSAKU}&#39;&quot;      /&gt;
 *     &lt;/og:where&gt;
 *     &lt;!-- ORDER BY句でAppearTagを使用すれば{&#064;ORDER_BY}がNULLの場合、ORDER BY句は無視されます。 --&gt;
 *     &lt;!-- また、{&#064;ORDER_BY}がNULLの場合に、defaultVal属性を指定すれば、その値でORDER BY表示されます。 --&gt;
 *     &lt;og:appear startKey = &quot;order by&quot; value = &quot;{&#064;ORDER_BY}&quot;
 *                 defaultVal = &quot;SYSTEM_ID,CLM,LANG&quot; /&gt;
 * &lt;/og:query&gt;
 *
 * @og.group 画面部品
 *
 * @version  4.0
 * @author	Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public class AppearTag extends CommonTagSupport {
	//* このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "5.7.8.1 (2014/07/18)" ;

	private static final long serialVersionUID = 578120140718L ;

	private String	startKey	= "";
	private String	value		;
	private String	defaultVal	;
	private boolean	quotCheck	= HybsSystem.sysBool( "USE_SQL_INJECTION_CHECK" );	// 5.7.8.1 (2014/07/18)
	private boolean	xssCheck	= HybsSystem.sysBool( "USE_XSS_CHECK" );			// 5.7.8.1 (2014/07/18)

	/**
	 * Taglibの終了タグが見つかったときに処理する doEndTag() を オーバーライドします。
	 *
	 * @og.rev 3.1.1.2 (2003/04/04) Tomcat4.1 対応。release2() を doEndTag()で呼ぶ。
	 * @og.rev 5.7.8.1 (2014/07/18) quotCheck,xssCheck 追加
	 *
	 * @return	後続処理の指示(EVAL_PAGE)
	 */
	@Override
	public int doEndTag() {
		debugPrint();		// 4.0.0 (2005/02/28)

		// 5.7.8.1 (2014/07/18) quotCheck,xssCheck 追加
		useQuotCheck( quotCheck );
		useXssCheck( xssCheck );

		String output = getRequestParameter( value );
		if( isNull() ) {
			output = defaultVal;
		}

		if( output != null ) {
			jspPrint( startKey + " " + output );
		}

		return EVAL_PAGE ;
	}

	/**
	 * タグリブオブジェクトをリリースします。
	 *
	 * キャッシュされて再利用されるので、フィールドの初期設定を行います。
	 *
	 * @og.rev 2.0.0.4 (2002/09/27) カスタムタグの release() メソッドを、追加
	 * @og.rev 3.1.1.2 (2003/04/04) Tomcat4.1 対応。release2() を doEndTag()で呼ぶ。
	 * @og.rev 5.7.8.1 (2014/07/18) quotCheck , xssCheck 追加
	 *
	 */
	@Override
	protected void release2() {
		super.release2();
		startKey    = "";
		value       = null;
		defaultVal  = null;
		quotCheck	= HybsSystem.sysBool( "USE_SQL_INJECTION_CHECK" );	// 5.7.8.1 (2014/07/18)
		xssCheck	= HybsSystem.sysBool( "USE_XSS_CHECK" );			// 5.7.8.1 (2014/07/18)
	}

	/**
	 * 【TAG】開始文字列を設定します(初期値:"")。
	 *
	 * @og.tag
	 * このキーは、バリューと接続される場合に空白文字を一つ挿入します。
	 *
	 * @param	val 開始文字列 (例：startKey="order by")
	 */
	public void setStartKey( final String val ) {
		startKey = nval( getRequestParameter( val ),startKey );
	}

	/**
	 * 【TAG】値をセットします(指定された値が 設定されている場合のみ使用されます)。
	 *
	 * @og.tag
	 * 指定された値が 設定されている場合のみ、開始文字列(startKey)と組み合わせれて、使用されます。
	 * これは、一般にvalue値が変動する場合に、defaultVal 等に重複する値を
	 * 設定したくない場合に使用します。{&#064;XXXX}文字が使用できます。
	 *
	 * @param	val 値
	 */
	public void setValue( final String val ) {
		value = val;
	}

	/**
	 * 【TAG】value属性に値がセットされていないとき使用する、初期値を指定します。
	 *
	 * @og.tag
	 * value属性に値がセットされていないときに、この初期値を使用します。
	 *
	 * @param	val 初期値
	 */
	public void setDefaultVal( final String val ) {
		defaultVal = nval( getRequestParameter( val ),defaultVal );
	}

	/**
	 * 【TAG】リクエスト情報の シングルクォート(') 存在チェックを実施するかどうか[true/false]を設定します
	 *		(初期値:USE_SQL_INJECTION_CHECK[={@og.value org.opengion.hayabusa.common.SystemData#USE_SQL_INJECTION_CHECK}])。
	 *
	 * @og.tag
	 * ＳＱＬインジェクション対策の一つとして、暫定的ではありますが、SQLのパラメータに
	 * 渡す文字列にシングルクォート(') を許さない設定にすれば、ある程度は防止できます。
	 * 数字タイプの引数には、 or 5=5 などのシングルクォートを使用しないコードを埋めても、
	 * 数字チェックで検出可能です。文字タイプの場合は、必ず (')をはずして、
	 * ' or 'A' like 'A のような形式になる為、(')チェックだけでも有効です。
	 * (') が含まれていたエラーにする(true)／かノーチェックか(false)を指定します。
	 * (初期値:システム定数のUSE_SQL_INJECTION_CHECK[={@og.value org.opengion.hayabusa.common.SystemData#USE_SQL_INJECTION_CHECK}])。
	 *
	 * @og.rev 4.0.0.0 (2005/08/31) 新規追加
	 *
	 * @param   flag クォートチェック [true:する/それ以外:しない]
	 * @see		org.opengion.hayabusa.common.SystemData#USE_SQL_INJECTION_CHECK
	 */
	public void setQuotCheck( final String flag ) {
		quotCheck = nval( getRequestParameter( flag ),quotCheck );
	}

	/**
	 * 【TAG】リクエスト情報の HTMLTag開始/終了文字(&gt;&lt;) 存在チェックを実施するかどうか[true/false]を設定します
	 *		(初期値:USE_XSS_CHECK[={@og.value org.opengion.hayabusa.common.SystemData#USE_XSS_CHECK}])。
	 *
	 * @og.tag
	 * クロスサイトスクリプティング(XSS)対策の一環としてless/greater than signについてのチェックを行います。
	 * (&gt;&lt;) が含まれていたエラーにする(true)／かノーチェックか(false)を指定します。
	 * (初期値:システム定数のUSE_XSS_CHECK[={@og.value org.opengion.hayabusa.common.SystemData#USE_XSS_CHECK}])。
	 *
	 * @og.rev 5.0.0.2 (2009/09/15) 新規追加
	 *
	 * @param	flag	XSSチェック [true:する/false:しない]
	 * @see		org.opengion.hayabusa.common.SystemData#USE_XSS_CHECK
	 */
	public void setXssCheck( final String flag ) {
		xssCheck = nval( getRequestParameter( flag ),xssCheck );
	}

	/**
	 * このオブジェクトの文字列表現を返します。
	 * 基本的にデバッグ目的に使用します。
	 *
	 * @return このクラスの文字列表現
	 * @og.rtnNotNull
	 */
	@Override
	public String toString() {
		return ToString.title( this.getClass().getName() )
				.println( "VERSION"		,VERSION	)
				.println( "startKey"	,startKey	)
				.println( "value"		,value		)
				.println( "defaultVal"	,defaultVal	)
				.println( "Other..."	,getAttributes().getAttribute() )
				.fixForm().toString() ;
	}
}
